summaryrefslogtreecommitdiffstats
path: root/src/mesa/main/texformat.c
diff options
context:
space:
mode:
authorMark Mueller <[email protected]>2014-01-04 14:11:43 -0800
committerMark Mueller <[email protected]>2014-01-27 14:28:46 -0800
commit71fe9437169cfdafda8814aa814bb85429fb6cfc (patch)
tree7eb5b04c681c7347de9dd5b0a69aa4f75343293d /src/mesa/main/texformat.c
parentbc0ed682757607172eca6b8a7031c81a73287524 (diff)
mesa: change gl_format to mesa_format
s/\bgl_format\b/mesa_format/g. Use better name for Mesa Formats enum
Diffstat (limited to 'src/mesa/main/texformat.c')
-rw-r--r--src/mesa/main/texformat.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mesa/main/texformat.c b/src/mesa/main/texformat.c
index d3aa4773614..0a993ede89b 100644
--- a/src/mesa/main/texformat.c
+++ b/src/mesa/main/texformat.c
@@ -54,12 +54,12 @@
* \param format incoming image pixel format.
* \param type incoming image data type.
*
* \return the closest gl_format for the given format/type arguments
*
* This is called via dd_function_table::ChooseTextureFormat. Hardware
* drivers may override this function with a specialized version.
*/
-gl_format
+mesa_format
_mesa_choose_tex_format(struct gl_context *ctx, GLenum target,
GLint internalFormat, GLenum format, GLenum type)
{
@@ -54,12 +54,12 @@
* \param type incoming image data type.
*
- * \return the closest gl_format for the given format/type arguments
+ * \return the closest mesa_format for the given format/type arguments
*
* This is called via dd_function_table::ChooseTextureFormat. Hardware